==> FlightGear-0.6.0.tar.gz: FlightGear-0.6.0/Simulator/FDM/JSBsim/FGOutput.h <==
/*******************************************************************************

 Header:       FGOutput.h
 Author:       Jon Berndt
 Date started: 12/2/98

 ------------- Copyright (C) 1999  Jon S. Berndt (jsb@hal-pc.org) -------------

 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation; either version 2 of the License, or (at your option) any later
 version.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 details.

 You should have received a copy of the GNU General Public License along with
 this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 Place - Suite 330, Boston, MA  02111-1307, USA.

 Further information about the GNU General Public License can also be found on
 the world wide web at http://www.gnu.org.

HISTORY
--------------------------------------------------------------------------------
12/02/98   JSB   Created

********************************************************************************
SENTRY
*******************************************************************************/

#ifndef FGOUTPUT_H
#define FGOUTPUT_H

/*******************************************************************************
INCLUDES
*******************************************************************************/

#include "FGModel.h"

using namespace std;

/*******************************************************************************
CLASS DECLARATION
*******************************************************************************/

class FGOutput : public FGModel
{
public:
  FGOutput(FGFDMExec*);
  ~FGOutput(void);

  bool Run(void);

  void ConsoleOutput(void);
  void DelimitedOutput(void);

protected:

private:
  bool FirstPass;
};

/******************************************************************************/
#endif

==> FlightGear-0.7.0.tar.gz: FlightGear-0.7.0/Simulator/FDM/JSBsim/FGOutput.h <==
/*******************************************************************************

 Header:       FGOutput.h
 Author:       Jon Berndt
 Date started: 12/2/98

 ------------- Copyright (C) 1999  Jon S. Berndt (jsb@hal-pc.org) -------------

 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation; either version 2 of the License, or (at your option) any later
 version.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 details.

 You should have received a copy of the GNU General Public License along with
 this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 Place - Suite 330, Boston, MA  02111-1307, USA.

 Further information about the GNU General Public License can also be found on
 the world wide web at http://www.gnu.org.

HISTORY
--------------------------------------------------------------------------------
12/02/98   JSB   Created

********************************************************************************
SENTRY
*******************************************************************************/

#ifndef FGOUTPUT_H
#define FGOUTPUT_H

/*******************************************************************************
INCLUDES
*******************************************************************************/

#include "FGModel.h"

#ifdef FGFS
#  include <Include/compiler.h>
#  ifdef FG_HAVE_STD_INCLUDES
#    include <iostream>
#    include <fstream>
#  else
#    include <iostream.h>
#    include <fstream.h>
#  endif
#else
#  include <iostream>
#  include <fstream>
#endif

//using namespace std;

/*******************************************************************************
CLASS DECLARATION
*******************************************************************************/

class FGOutput : public FGModel
{
public:
  FGOutput(FGFDMExec*);
  ~FGOutput(void);

  bool Run(void);

  void DelimitedOutput(void);
  void DelimitedOutput(string);

protected:

private:
  bool FirstPass;
  ofstream datafile;
};

/******************************************************************************/
#endif
